@@ -254,8 +254,6 @@ proctable_free_info (ProcInfo *info)
 		g_free (info->user);
 	if (info->status)
 		g_free (info->status);
-	if (info->pixbuf)
-		g_object_unref (info->pixbuf);
 	g_free (info);
 }
 
@@ -526,6 +524,7 @@ static void
 update_info (ProcData *procdata, ProcInfo *info, gint pid)
 {
 	GtkTreeModel *model;
+	GtkTreePath *path;
 	glibtop_proc_state procstate;
 	glibtop_proc_mem procmem;
 	glibtop_proc_uid procuid;
@@ -573,6 +572,16 @@ update_info (ProcData *procdata, ProcInfo *info, gint pid)
 	}
 	
 	if (info->visible) {
+		GdkRectangle rect, vis_rect;
+		path = gtk_tree_model_get_path (model, &info->node);
+		gtk_tree_view_get_cell_area (GTK_TREE_VIEW (procdata->tree),
+								      path, 	NULL, &rect);
+		gtk_tree_view_get_visible_rect (GTK_TREE_VIEW (procdata->tree),
+									   &vis_rect);
+		gtk_tree_path_free (path);
+		/* Don't update if row is not visible. Small performance improvement */
+		if ((rect.y < 0) || (rect.y > vis_rect.height))
+			return;
 		mem = get_size_string (info->mem);
 		vmsize = get_size_string (info->vmsize);
 		memres = get_size_string (info->memres);
@@ -636,7 +645,7 @@ get_info (ProcData *procdata, gint pid)
 	else
 		info->arguments = g_strdup ("");
 	
-	if (pwd && pwd->pw_name)
+	if (pwd->pw_name)
 		info->user = g_strdup_printf ("%s", pwd->pw_name);
 	else
 		info->user = NULL;
@@ -914,7 +923,7 @@ proctable_search_table (ProcData *procdata, gchar *string)
 			gtk_tree_path_free (node);
 		}
 		
-		if (info->user && strstr (info->user, string) && info->visible)
+		if (strstr (info->user, string) && info->visible)
 		{
 			GtkTreePath *node = gtk_tree_model_get_path (model, &info->node);
 			
